@@ -76,7 +76,7 @@ var items
 function start(items_) {
     items = items_
     currentLevel = 0
-    items.score.currentSubLevel = 1
+    items.score.currentSubLevel = 0
     initLevel()
 }
 
@@ -108,7 +108,7 @@ function nextLevel() {
     if(levels.length <= ++currentLevel ) {
         currentLevel = 0
     }
-    items.score.currentSubLevel = 1
+    items.score.currentSubLevel = 0
     initLevel();
 }
 
@@ -116,7 +116,7 @@ function previousLevel() {
     if(--currentLevel < 0) {
         currentLevel = levels.length - 1
     }
-    items.score.currentSubLevel = 1
+    items.score.currentSubLevel = 0
     initLevel();
 }
 
@@ -140,7 +140,7 @@ function displayNextHand() {
     items.score.playWinAnimation();
     if(currentHands.length <= ++currentImageId ) {
         items.bonus.good("flower")
-        nextLevel()
+        return
     }
     displayHand()
 }
