@@ -2,10 +2,12 @@
  *
  * Copyright (C) 2014 Holger Kaelberer
  *               2016 Akshat Tandon
+ *               2020 Timothée Giet
  *
  * Authors:
  *   Holger Kaelberer <holger.k@elberer.de> (Qt Quick port of click-on-letter)
  *   Akshat Tandon    <akshat.tandon@research.iiit.ac.in>
+ *   Timothée Giet <animtim@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -29,7 +31,6 @@
 
 var url = "qrc:/gcompris/src/activities/letter-in-word/resource/"
 var resUrl = "qrc:/gcompris/src/activities/braille_fun/resource/"
-var resUrl2 = "qrc:/gcompris/src/activities/click_on_letter/resource/"
 
 var levels;
 var currentLevel;
@@ -46,13 +47,12 @@ var incorrectFlag = false;
 var locale;
 
 function start(_items) {
-    Core.checkForVoices(_items.main);
     items = _items;
     // register the voices for the locale
-    locale = GCompris.ApplicationInfo.getVoicesLocale(items.locale)
-    GCompris.DownloadManager.updateResource(GCompris.DownloadManager.getVoicesResourceForLocale(locale))
+    locale = GCompris.ApplicationInfo.getVoicesLocale(items.locale);
+    GCompris.DownloadManager.updateResource(GCompris.DownloadManager.getVoicesResourceForLocale(locale));
     loadDataset();
-    levels = Lang.getAllLessons(dataset)
+    levels = Lang.getAllLessons(dataset);
     currentLevel = 0;
     currentSubLevel = 0;
     maxLevel = levels.length;
@@ -60,10 +60,12 @@ function start(_items) {
 }
 
 function loadDataset() {
-    var resourceUrl = "qrc:/gcompris/src/activities/lang/resource/"
+    var resourceUrl = "qrc:/gcompris/src/activities/lang/resource/";
     var data = Lang.loadDataset(items.parser, resourceUrl, locale);
     dataset = data["dataset"];
     items.background.englishFallback = data["englishFallback"];
+    if(!items.background.englishFallback)
+        Core.checkForVoices(items.activityPage);
 }
 
 function stop() {
@@ -102,8 +104,8 @@ function initLevel() {
             items.wordsModel.append({
                                         "spelling": words[i].translatedTxt,
                                         "imgurl": words[i].image,
-                                        "selected": false,
-                                        "voice": words[i].voice
+                                        "voice": words[i].voice,
+                                        "selected": false
                                     });
         }
     }
@@ -138,14 +140,12 @@ function initLevel() {
 
 function calculateFrequency() {
     var freq = [];
-    //regex pattern to detect whether the character is an english alphabet or some accented latin character
-    var pattern = /[A-Za-z\u00C0-\u017F]/;
     for(var i = 0; i < words.length; i++) {
         var currentWord = words[i].translatedTxt;
         for(var j = 0; j < currentWord.length; j++) {
             var character = currentWord.charAt(j);
-            //consider the character if and only if it is an alphabet or an accented latin character
-            if(pattern.test(character)) {
+            //consider the character if it is not a space
+            if(character != " ") {
                 if(freq[character]) {
                     freq[character]++;
                 }
@@ -231,7 +231,7 @@ function checkAnswer() {
 }
 
 function checkWord(index) {
-    var modelEntry = items.wordsModel.get(index);
-    items.wordsModel.setProperty(index, "selected", !modelEntry.selected);
-    return modelEntry.selected;
+    var itemStatus = !items.wordsModel.get(index).selected;
+    items.wordsModel.setProperty(index, "selected", itemStatus);
+    return itemStatus;
 }
