@@ -31,7 +31,6 @@ var iceBlocksLayout = [[0, 0],[1, 0],[2, 0],[3, 0],[4, 0],
 
 var tuxIceBlockNumber = 0
 var tuxIceBlockNumberGoal = 0
-var tuxIsMoving = false;
 var placeFishToReachBool = false
 
 var level = null;
@@ -71,7 +70,7 @@ function stop() {
 
 function initLevel() {
     items.bar.level = currentLevel + 1
-
+    items.tuxIsMoving = false;
     items.chooseDiceBar.value1 = 0
     items.chooseDiceBar.value2 = 0
     items.chooseDiceBar.valueMax = items.levels[currentLevel].maxNumber
@@ -87,8 +86,8 @@ function initLevel() {
     items.clockPosition = 4
 }
 
-function moveTux() {
-    calculateTuxIceBlockNextPos()
+function moveTux(numberOfMovesToDo) {
+    calculateTuxIceBlockNextPos(numberOfMovesToDo)
 
     if (tuxIceBlockNumberGoal > fishIndex)
     {
@@ -104,7 +103,7 @@ function moveTux() {
 }
 
 function moveTuxToNextIceBlock() {
-    tuxIsMoving = false
+    items.tuxIsMoving = false
     tuxIceBlockNumber++
     tuxIceBlockNumber = tuxIceBlockNumber % iceBlocksLayout.length
 
@@ -122,7 +121,7 @@ function moveTuxToNextIceBlock() {
     var fishPos = fishIndex % iceBlocksLayout.length
     //if tux reaches its position + dice number
     if (tuxIceBlockNumber == fishPos) {
-        tuxIsMoving = false;
+        items.tuxIsMoving = false;
 
         // if last fish reached
         if (--numberOfFish == 0) {
@@ -146,10 +145,10 @@ function moveTuxToNextIceBlock() {
             lost()
             return
         }
-        tuxIsMoving = false;
+        items.tuxIsMoving = false;
         return
     }
-    tuxIsMoving = true
+    items.tuxIsMoving = true
 }
 
 function moveTuxToIceBlock() {
@@ -160,7 +159,7 @@ function moveTuxToIceBlock() {
 }
 
 function tuxRunningChanged() {
-    if (tuxIsMoving) {
+    if (items.tuxIsMoving) {
         moveTuxToNextIceBlock()
     } else {
         if (placeFishToReachBool == true) {
@@ -170,12 +169,10 @@ function tuxRunningChanged() {
     }
 }
 
-function calculateTuxIceBlockNextPos() {
-    tuxIceBlockNumberGoal = tuxIceBlockNumber +
-            items.chooseDiceBar.value1 + items.chooseDiceBar.value2
+function calculateTuxIceBlockNextPos(numberOfMovesToDo) {
+    tuxIceBlockNumberGoal = (tuxIceBlockNumber + numberOfMovesToDo) % iceBlocksLayout.length
     // Increase Tux's speed depending on the number of blocks to move
-    items.tux.duration = 1000 -
-            (items.chooseDiceBar.value1 + items.chooseDiceBar.value2) * 40
+    items.tux.duration = 1000 - numberOfMovesToDo * 40
 }
 
 var previousFishIndex = 0
