@@ -35,15 +35,15 @@ var tutorials = [
                 qsTr("Press the + button to increase the velocity, or the - button to decrease the velocity."),
             ],
             [
-                qsTr("The item next to the engine is the Ballast tanks."),
-                qsTr("The Ballast tanks are used to float or dive under water."),
+                qsTr("The item next to the engine is the ballast tank."),
+                qsTr("The ballast tanks are used to float or dive under water."),
                 qsTr("If the ballast tanks are empty, the submarine will float. If the ballast tanks are full of water, the submarine will dive underwater."),
-                qsTr("Turning the upper valve on or off will alternatively allow or stop water from filling in the Ballast tanks, thus allowing it to dive underwater."),
-                qsTr("Turning the lower valve on or off will alternatively allow or stop water from flushing out the Ballast tanks, thus allowing it to float on the surface of the water."),
+                qsTr("Turning the upper valve on or off will alternatively allow or stop the water from filling in the ballast tank, thus allowing it to dive underwater."),
+                qsTr("Turning the lower valve on or off will alternatively allow or stop the water from flushing out the ballast tank, thus allowing it to float on the surface of the water."),
             ],
             [
                 qsTr("The rightmost item in the control panel controls the diving planes of the submarine"),
-                qsTr("The Diving Planes in a submarine is used to control the depth of the submarine accurately once it is underwater."),
+                qsTr("The diving planes in a submarine are used to control the depth of the submarine accurately once it is underwater."),
                 qsTr("Once the submarine is moving underwater, increasing or decreasing the angle of the planes will increase and decrease the depth of the submarine."),
                 qsTr("The + button will increase the depth of the submarine, while the - button will decrease the depth of the submarine."),
                 qsTr("Grab the crown to open the gate."),
